import * as TypeDoc from 'typedoc';
import { DocumentedClass, DocumentedFunction, DocumentedTypes } from './serializers';
import { MarkdownGeneratorMarkdownBuild } from './generators/MarkdownGenerator';
export type MicroDocgenLink = Record<string, string>;
export { LogLevel as DebugLogLevel } from 'typedoc';
/**
 * Interface for initializing MicroDocgen.
 */
export interface MicroDocgenInit {
    jsonInputPath?: string | null;
    input?: string[] | null;
    jsonName?: string;
    output?: string;
    noEmit?: boolean;
    custom?: MicroDocgenCustomFile[];
    tsconfigPath?: string;
    print?: boolean;
    spaces?: number;
    markdown?: boolean;
    includeMarkdownHeaders?: boolean;
    noLinkTypes?: boolean;
    extension?: string;
    links?: MicroDocgenLink;
    debug?: TypeDoc.LogLevel | 'Verbose' | 'Info' | 'Warn' | 'Error' | 'None';
    flattenSingleModule?: boolean;
    clean?: boolean;
    typeLinker?: (type: string, ref: string[]) => string;
    typeLinkerBasePath?: string;
    omitTypeLinkerExtension?: boolean;
}
/**
 * Interface for custom files in MicroDocgen.
 */
export interface MicroDocgenCustomFile {
    name: string;
    path: string;
    category: string;
    type?: string;
}
/**
 * Interface for documentation metadata.
 */
export interface DocumentationMetadata {
    timestamp: number;
    generationMs: number;
}
/**
 * Interface for the generated documentation.
 */
export interface Documentation {
    custom: Record<string, (MicroDocgenCustomFile & {
        content: string;
    })[]>;
    modules: Record<string, {
        name: string;
        classes: {
            markdown: MarkdownGeneratorMarkdownBuild[];
            data: DocumentedClass;
        }[];
        types: {
            markdown: MarkdownGeneratorMarkdownBuild[];
            data: DocumentedTypes;
        }[];
        functions: {
            markdown: MarkdownGeneratorMarkdownBuild[];
            data: DocumentedFunction;
        }[];
        variables: {
            markdown: MarkdownGeneratorMarkdownBuild[];
            data: DocumentedTypes;
        }[];
        enum: {
            markdown: MarkdownGeneratorMarkdownBuild[];
            data: DocumentedTypes;
        }[];
    }>;
    metadata: DocumentationMetadata;
}
/**
 * Creates documentation based on the provided options.
 * @param options - The initialization options for MicroDocgen.
 * @returns The generated documentation.
 */
export declare function createDocumentation(options: MicroDocgenInit): Promise<Documentation>;
export default createDocumentation;
