import { JSONOutput } from 'typedoc';
import { FileMetadata } from '../utils';
import { AbstractSerializer } from './AbstractSerializer';
export interface DocumentedClass {
    name: string;
    description: string | null;
    see: string[];
    extends: string | null;
    rawExtends: string[] | null;
    implements: string | null;
    rawImplements: string[] | null;
    private: boolean;
    abstract: boolean;
    deprecated: boolean;
    constructor: DocumentedClassConstructor | null;
    methods: DocumentedClassMethod[];
    properties: DocumentedClassProperty[];
    metadata: FileMetadata | null;
}
export interface DocumentedClassConstructor extends DocumentedClassMethod {
    constructor: string;
}
export interface DocumentedClassProperty {
    name: string;
    description: string | null;
    see: string[];
    static: boolean;
    private: boolean;
    readonly: boolean;
    abstract: boolean;
    deprecated: boolean;
    default: string | null;
    type: string | null;
    rawType: string[] | null;
    metadata: FileMetadata | null;
}
export interface DocumentedParameter {
    name: string;
    description: string | null;
    optional: boolean;
    default: string | null;
    type: string | null;
    rawType: string[] | null;
}
export interface DocumentedClassMethod {
    name: string;
    description: string | null;
    see: string[];
    static: boolean;
    private: boolean;
    examples: string[];
    abstract: boolean;
    deprecated: boolean;
    parameters: DocumentedParameter[];
    returns: {
        type: string;
        rawType: string[] | null;
        description: string | null;
    } | null;
    metadata: FileMetadata | null;
}
export declare class ClassSerializer extends AbstractSerializer {
    serialize(): DocumentedClass;
    parseProperties(decl: JSONOutput.DeclarationReflection): DocumentedClassProperty;
    parseMethod(decl: JSONOutput.DeclarationReflection): DocumentedClassMethod;
    parseParameter(decl: JSONOutput.TypeParameterReflection): DocumentedParameter;
}
