export type HeadingTypes = 1 | 2 | 3 | 4 | 5 | 6;
export type MdHeading<T extends string> = `# ${T}` | `## ${T}` | `### ${T}` | `#### ${T}` | `##### ${T}` | `###### ${T}`;
export declare function heading<T extends string>(src: T): `# ${T}`;
export declare function heading<T extends string>(src: T, type: 1): `# ${T}`;
export declare function heading<T extends string>(src: T, type: 2): `## ${T}`;
export declare function heading<T extends string>(src: T, type: 3): `### ${T}`;
export declare function heading<T extends string>(src: T, type: 4): `#### ${T}`;
export declare function heading<T extends string>(src: T, type: 5): `##### ${T}`;
export declare function heading<T extends string>(src: T, type: 6): `###### ${T}`;
export declare function headingId<T extends string, U extends string>(src: T, id: U, type?: HeadingTypes): `<h${HeadingTypes} id="${U}">${T}</h${HeadingTypes}>`;
export declare function code<T extends string>(src: T): `\`${T}\``;
export declare function codeBlock<T extends string, U extends string>(src: T, lang?: U): `\`\`\`
${T}
\`\`\`` | `\`\`\`${U}
${T}
\`\`\``;
export declare function bold<T extends string>(src: T): `**${T}**`;
export declare function italic<T extends string>(src: T): `*${T}*`;
export declare function strikethrough<T extends string>(src: T): `~~${T}~~`;
export declare function subscript<T extends string>(src: T): `~${T}~`;
export declare function superscript<T extends string>(src: T): `^${T}^`;
export declare function highlight<T extends string>(src: T): `==${T}==`;
export declare function taskList<T extends string>(src: T): `[] ${T}`;
export declare function taskList<T extends string>(src: T, checked?: false): `[] ${T}`;
export declare function taskList<T extends string>(src: T, checked: true): `[x] ${T}`;
export declare function blockquote<T extends string>(src: T): `> ${T}`;
export declare function ul<T extends string>(src: T): `- ${T}`;
export declare function ol<T extends string>(src: T): `${number}. ${T}`;
export declare function hr(): "---";
export declare function hyperlink<T extends string, U extends string>(text: T, link: U): `[${T}](${U})`;
export declare function image<T extends string, U extends string>(alt: T, link: U): `![${T}](${U})`;
export declare function table(heading: string[], body: string[][]): string;
